Struct EndOfEpochData
pub struct EndOfEpochData {
pub next_epoch_committee: Vec<ValidatorCommitteeMember>,
pub next_epoch_protocol_version: u64,
pub epoch_commitments: Vec<CheckpointCommitment>,
pub epoch_supply_change: i64,
}Expand description
Data, which when included in a [CheckpointSummary], signals the end of an
Epoch.
BCS
The BCS serialized form for this type is defined by the following ABNF:
end-of-epoch-data = (vector validator-committee-member) ; next-epoch-committee
u64 ; next-epoch-protocol-version
(vector checkpoint-commitment) ; epoch-commitments
i64 ; epoch-supply-changeFields
next_epoch_committee: Vec<ValidatorCommitteeMember>The set of Validators that will be in the ValidatorCommittee for the next epoch.
next_epoch_protocol_version: u64The protocol version that is in effect during the next epoch.
epoch_commitments: Vec<CheckpointCommitment>Commitments to epoch specific state (e.g. live object set)
epoch_supply_change: i64The number of tokens that were minted (if positive) or burnt (if negative) in this epoch.